"use client";

import { useEffect, useState } from "react";

import { Locale } from "@/i18n/routing";
import { cn } from "@/lib/utils";

interface CountdownTimerProps {
  endTime: string;
  locale: Locale;
  className?: string;
}

export function CountdownTimer({
  endTime,
  locale,
  className,
}: CountdownTimerProps) {
  const [timeLeft, setTimeLeft] = useState({
    hours: 0,
    minutes: 0,
    seconds: 0,
  });

  useEffect(() => {
    const endDate = new Date(endTime).getTime();

    const timer = setInterval(() => {
      const now = new Date().getTime();
      const distance = endDate - now;

      if (distance < 0) {
        clearInterval(timer);
        return;
      }

      const hours = Math.floor(
        (distance % (1000 * 60 * 60 * 24)) / (1000 * 60 * 60)
      );
      const minutes = Math.floor((distance % (1000 * 60 * 60)) / (1000 * 60));
      const seconds = Math.floor((distance % (1000 * 60)) / 1000);

      setTimeLeft({ hours, minutes, seconds });
    }, 1000);

    return () => clearInterval(timer);
  }, [endTime]);

  const formatNumber = (num: number) => num.toString().padStart(2, "0");

  return (
    <div
      className={cn(
        "flex items-center gap-1 rounded-md px-3 py-1 text-sm font-medium",
        className
      )}
    >
      {locale === "ar" ? (
        <>
          <span>{formatNumber(timeLeft.seconds)}</span>
          <span>:</span>
          <span>{formatNumber(timeLeft.minutes)}</span>
          <span>:</span>
          <span>{formatNumber(timeLeft.hours)}</span>
        </>
      ) : (
        <>
          <span>{formatNumber(timeLeft.hours)}</span>
          <span>:</span>
          <span>{formatNumber(timeLeft.minutes)}</span>
          <span>:</span>
          <span>{formatNumber(timeLeft.seconds)}</span>
        </>
      )}
    </div>
  );
}
